about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/configuration-common.nix
diff options
context:
space:
mode:
authorRobert Hensing <robert@roberthensing.nl>2023-11-10 18:38:25 +0100
committerRobert Hensing <robert@roberthensing.nl>2023-11-10 18:38:25 +0100
commit743a7a597fa7d275f44e1f40420ca3d43df80de1 (patch)
treeb51397f79d06cdfb06da4ae7d3dcc08de672e127 /pkgs/development/haskell-modules/configuration-common.nix
parentd92b7a7f3741cadcc93557f1f2aab4f052b26c20 (diff)
haskellPackages: Fixup hspec-core minor version in overrides
Diffstat (limited to 'pkgs/development/haskell-modules/configuration-common.nix')
-rw-r--r--pkgs/development/haskell-modules/configuration-common.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkgs/development/haskell-modules/configuration-common.nix b/pkgs/development/haskell-modules/configuration-common.nix
index 922cd118a662d..651d260a4947c 100644
--- a/pkgs/development/haskell-modules/configuration-common.nix
+++ b/pkgs/development/haskell-modules/configuration-common.nix
@@ -57,7 +57,7 @@ self: super: {
           # not solvable short of recompiling GHC. Instead of adding
           # allowInconsistentDependencies for all reverse dependencies of hspec-core,
           # just upgrade to an hspec version without the offending dependency.
-          hspec-core = cself.hspec-core_2_11_6;
+          hspec-core = cself.hspec-core_2_11_7;
           hspec-discover = cself.hspec-discover_2_11_6;
           hspec = cself.hspec_2_11_6;
 
@@ -1673,7 +1673,7 @@ self: super: {
   # Give latest hspec correct dependency versions without overrideScope
   hspec_2_11_6 = doDistribute (super.hspec_2_11_6.override {
     hspec-discover = self.hspec-discover_2_11_6;
-    hspec-core = self.hspec-core_2_11_6;
+    hspec-core = self.hspec-core_2_11_7;
   });
   hspec-meta_2_11_6 = doDistribute (super.hspec-meta_2_11_6.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
@@ -1681,9 +1681,9 @@ self: super: {
   hspec-discover_2_11_6 = doDistribute (super.hspec-discover_2_11_6.override {
     hspec-meta = self.hspec-meta_2_11_6;
   });
   # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_6
   # is overlayed to hspec-core.
-  hspec-core_2_11_6 = doDistribute (dontCheck (super.hspec-core_2_11_6.override {
+  hspec-core_2_11_7 = doDistribute (dontCheck (super.hspec-core_2_11_7.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
   }));
@@ -1681,9 +1681,9 @@ self: super: {
     hspec-meta = self.hspec-meta_2_11_6;
   });
-  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_6
+  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_7
   # is overlayed to hspec-core.